@@ -32,7 +32,7 @@ import os
 import os.path as path
 import tempfile
 import shutil
-import popen2
+import subprocess
 import argparse
 import sys
 
@@ -72,11 +72,12 @@ def cmd_cdiff(ns):
     config = apacheconf.Config(ns.file)
     transform.transform_config(config)
 
-    r,w = popen2.popen2('diff -u "%s" - | colordiff' % ns.file)
-    w.write(config.dump())
-    w.close()
-    sys.stdout.write(r.read())
-    r.close()
+    pipe = subprocess.Popen(
+        'diff -u "%s" - | colordiff' % ns.file,
+        shell=True, stdin=subprocess.PIPE, stdout=subprocess.PIPE)
+    pipe.stdin.write(config.dump())
+    pipe.stdin.close()
+    sys.stdout.write(pipe.stdout.read())
 
     return 0
 
